Evaluate a character vector as a dataframe (a tbl_df)
Source: R/Functions-Txt.R
evalTextAsDataframe.RdFunction to evaluate a character vector as a dataframe (a tbl_df).
Value
a dataframe (actually a tbl_df, see tibble::tibble())
Details
Each element in char_vec is regarded as a line of text (as in a text file).
The dataframe structure and column types are determined by readr::read_table().
This function differs from extractDataframe() in that, after comments are removed are
removed from the input character vector char_vec, the resulting
character vector is regarded as defining the dataframe. In extractDataframe(),
the input character vector may be a much larger section of text than what defines the
dataframe to be extracted, but the number of rows (n) to extract is known as, is the index of
the element to begin with (start).