Extract a dataframe (a tibble::tibble()) from a character vector
Source: R/Functions-Txt.R
extractDataframe.RdFunction to a dataframe (a tibble::tibble()) from a character vector.
Details
Each element in txt is regarded as a line of text (as in a text file).
The dataframe structure and column types are determined by readr::read_table().
txt - character vector of length
nwith comment lines removed (i.e., a subset oftxt)end - index of the last element extracted in the input
txtvector
This function differs from evalTextAsDataframe() in that
the input character vector may be a much larger section of text than what defines the
dataframe to be extracted, but the number of rows (n) to extract is known, as is the index of
the element to begin with (start). In evalTextAsDataframe(), after comments are removed are
removed from the input character vector char_vec, the resulting
character vector is regarded as defining the dataframe.