Function to remove strings starting with a comment character.
Examples
txt = c("#this is a comment",
" #so is this,even thought the line starts with blank space",
"this is not a comment",
"this is not either, but the first is line 3.");
removeCommentLines(txt); #--should be \code{txt[3:4]}
#> [1] "this is not a comment"
#> [2] "this is not either, but the first is line 3."