Function to identify the index of the first non-comment line in a character vector.
Details
Each element in txt is regarded as a line of text (as in a text file).
The function searches for the first non-comment line and returns its index.
Examples
txt = c("#this is a comment",
" #so is this,even thought the line starts with blank space",
"this is not a comment",
"this is not either, but the first is line 3.");
extractLines(txt,1); #--should be 3: txt[3] is first non-comment line
#> Error in extractLines(txt, 1): argument "end" is missing, with no default