Function to split text string to a character vector.
Details
The text is plit into a character vector using stringr::str_split_1().
Function to split text string to a character vector.
The text is plit into a character vector using stringr::str_split_1().